==> haskell-bencode-0.6.1.1-24-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-bencode.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 bencode
version:              0.6.1.1
visibility:           public
id:                   bencode-0.6.1.1-CZMYUhvpmo6Im7TNRvCgfS
key:                  bencode-0.6.1.1-CZMYUhvpmo6Im7TNRvCgfS
license:              BSD-3-Clause
copyright:
    (c) 2005-2009, David Himmelstrup,
    (c) 2006 Lemmih <lemmih@gmail.com>,
    (c) 2005 Jesper Louis Andersen <jlouis@mongers.org>

maintainer:           Peter Simons <simons@cryp.to>
author:
    Lemmih <lemmih@gmail.com>,
    Jesper Louis Andersen <jlouis@mongers.org>,
    Christopher Reichert <creichert07@gmail.com>

synopsis:             Parsers and printers for bencoded data.
description:
    Parsers and printers for bencoded data. Bencode (pronounced like B
    encode) is the encoding used by the peer-to-peer file sharing system
    BitTorrent for storing and transmitting loosely structured data.

category:             Text
abi:                  80fb7b41eb74488f22a8b9e38711ec77
exposed:              True
exposed-modules:
    Data.BEncode Data.BEncode.Lexer Data.BEncode.Parser
    Data.BEncode.Reader

import-dirs:          /usr/lib/ghc-8.10.2/site-local/bencode-0.6.1.1
library-dirs:         /usr/lib/ghc-8.10.2/site-local/bencode-0.6.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/bencode-0.6.1.1
hs-libraries:         HSbencode-0.6.1.1-CZMYUhvpmo6Im7TNRvCgfS
depends:
    base-4.14.1.0 binary-0.8.8.0 bytestring-0.10.10.0
    containers-0.6.2.1 parsec-3.1.14.0 transformers-0.5.6.2
    transformers-compat-0.6.5-E9Rid1zC4al974cN3f5HFc

haddock-interfaces:   /usr/share/doc/haskell-bencode/html/bencode.haddock
haddock-html:         /usr/share/doc/haskell-bencode/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-bencode-0.6.1.1-25-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-bencode.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 bencode
version:              0.6.1.1
visibility:           public
id:                   bencode-0.6.1.1-EN70ojoP7Ux9r3OsjUo2DS
key:                  bencode-0.6.1.1-EN70ojoP7Ux9r3OsjUo2DS
license:              BSD-3-Clause
copyright:
    (c) 2005-2009, David Himmelstrup,
    (c) 2006 Lemmih <lemmih@gmail.com>,
    (c) 2005 Jesper Louis Andersen <jlouis@mongers.org>

maintainer:           Peter Simons <simons@cryp.to>
author:
    Lemmih <lemmih@gmail.com>,
    Jesper Louis Andersen <jlouis@mongers.org>,
    Christopher Reichert <creichert07@gmail.com>

synopsis:             Parsers and printers for bencoded data.
description:
    Parsers and printers for bencoded data. Bencode (pronounced like B
    encode) is the encoding used by the peer-to-peer file sharing system
    BitTorrent for storing and transmitting loosely structured data.

category:             Text
abi:                  244d7784620b2bd4eafa7774c65c8c7b
exposed:              True
exposed-modules:
    Data.BEncode Data.BEncode.Lexer Data.BEncode.Parser
    Data.BEncode.Reader

import-dirs:          /usr/lib/ghc-8.10.2/site-local/bencode-0.6.1.1
library-dirs:         /usr/lib/ghc-8.10.2/site-local/bencode-0.6.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/bencode-0.6.1.1
hs-libraries:         HSbencode-0.6.1.1-EN70ojoP7Ux9r3OsjUo2DS
depends:
    base-4.14.1.0 binary-0.8.8.0 bytestring-0.10.10.0
    containers-0.6.2.1 parsec-3.1.14.0 transformers-0.5.6.2
    transformers-compat-0.6.6-5ZJJ9POl5DGLIWTn4Z8HjM

haddock-interfaces:   /usr/share/doc/haskell-bencode/html/bencode.haddock
haddock-html:         /usr/share/doc/haskell-bencode/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
